@@ -1,12 +1,12 @@
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(standardize)
 
 summary(ptk)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mean(ptk$cdur)
 sd(ptk$cdur)
 
@@ -15,7 +15,7 @@ sd(ptk$speechrate)
 
 summary(lm(cdur ~ speechrate, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$cdur_scaled <- scale(ptk$cdur)[, 1]
 ptk$sr_scaled <- scale(ptk$speechrate)[, 1]
 
@@ -27,7 +27,7 @@ sd(ptk$sr_scaled)
 
 summary(lm(cdur_scaled ~ sr_scaled, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$sr_scaled_by_speaker <- scale_by(speechrate ~ speaker, ptk)
 
 mean(ptk$sr_scaled_by_speaker)
@@ -42,7 +42,7 @@ with(ptk, tapply(sr_scaled, speaker, sd))
 with(ptk, tapply(sr_scaled_by_speaker, speaker, mean))
 with(ptk, tapply(sr_scaled_by_speaker, speaker, sd))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$sr_scaled_0.5 <- scale(ptk$speechrate) * 0.5
 ptk$sr_scaled_by_speaker_0.5 <- scale_by(speechrate ~ speaker, ptk, scale = 0.5)
 
@@ -52,33 +52,33 @@ sd(ptk$sr_scaled_0.5)
 with(ptk, tapply(sr_scaled_by_speaker_0.5, speaker, mean))
 with(ptk, tapply(sr_scaled_by_speaker_0.5, speaker, sd))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 options(contrasts = c("contr.treatment", "contr.poly"))
 
 contrasts(ptk$prevowel)
 
 summary(lm(cdur_scaled ~ prevowel, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 options(contrasts = c("contr.sum", "contr.poly"))
 
 contrasts(ptk$prevowel)
 
 summary(lm(cdur_scaled ~ prevowel, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 contrasts(ptk$prevowel) <- named_contr_sum(ptk$prevowel)
 
 contrasts(ptk$prevowel)
 
 summary(lm(cdur_scaled ~ prevowel, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 contrasts(ptk$prevowel) <- named_contr_sum(ptk$prevowel, scale = 0.5)
 
 contrasts(ptk$prevowel)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$prehigh <- ptk$prevowel %in% c("i", "u")
 
 class(ptk$prehigh)
@@ -93,7 +93,7 @@ levels(ptk$prehigh)
 
 contrasts(ptk$prehigh)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$preheight <- "Mid"
 ptk$preheight[ptk$prevowel == "a"] <- "Low"
 ptk$preheight[ptk$prevowel %in% c("i", "u")] <- "High"
@@ -104,7 +104,7 @@ head(ptk$preheight)
 
 contrasts(ptk$preheight)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 contr3 <- contr.poly(3)
 contr5 <- contr.poly(5)
 
@@ -114,7 +114,7 @@ apply(contr5, 2, mean)
 apply(contr3, 2, sd)
 apply(contr5, 2, sd)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 sc_1_contr3 <- scaled_contr_poly(3)
 sc_0.5_contr3 <- scaled_contr_poly(3, scale = 0.5)
 
@@ -126,7 +126,7 @@ sc_0.5_contr3
 
 apply(sc_0.5_contr3, 2, sd)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 contrasts(ptk$preheight)
 
 summary(lm(cdur_scaled ~ preheight, ptk))
@@ -137,7 +137,7 @@ contrasts(ptk$preheight)
 
 summary(lm(cdur_scaled ~ preheight, ptk))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ptk$preheight <- "Mid"
 ptk$preheight[ptk$prevowel == "a"] <- "Low"
 ptk$preheight[ptk$prevowel %in% c("i", "u")] <- "High"
@@ -147,7 +147,7 @@ ptk$preheight <- factor(ptk$preheight, ordered = TRUE, levels = c("Low",
 sobj <- standardize(cdur ~ place + stress + preheight + log(wordfreq) +
   scale_by(speechrate ~ speaker) + (1 | speaker), ptk)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 is.standardized(sobj)
 
 sobj
@@ -170,7 +170,7 @@ sobj$contrasts
 
 sobj$groups
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 sobj <- standardize(cdur ~ place + stress + preheight + log(wordfreq) +
   scale_by(speechrate ~ speaker) + (1 | speaker), ptk, scale = 0.5)
 
@@ -194,14 +194,14 @@ sobj$contrasts
 
 sobj$groups
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(lme4)
 
 mod <- lmer(sobj$formula, sobj$data)
 
 summary(mod)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 newdata <- predict(sobj, ptk)
 newdata_fe <- predict(sobj, ptk, random = FALSE)
 newdata_re <- predict(sobj, ptk, fixed = FALSE)
@@ -212,7 +212,7 @@ head(newdata_fe)
 
 head(newdata_re)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # predictions using both the fixed and random effects
 preds <- predict(mod, newdata = newdata)
 all.equal(preds, fitted(mod))
@@ -224,17 +224,17 @@ head(preds)
 
 head(preds_fe)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(afex)
 
 pvals <- mixed(mod, data = sobj$data, check_contrasts = FALSE)
 
 pvals
 
-## ------------------------------------------------------------------------
-library(lsmeans)
+## -----------------------------------------------------------------------------
+library(emmeans)
 
-stress_comparisons <- lsmeans(mod, pairwise ~ stress)
+stress_comparisons <- emmeans(mod, pairwise ~ stress)
 
 stress_comparisons
 
